using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;


namespace CCC_Demo
{
    public partial class CCC_CPCI_Demo : Form
    {
        public CCC_CPCI_Demo()
        {
            InitializeComponent();
        }

        private void SetCfg_Click(object sender, EventArgs e)
        {
            int card = 0;
            int synres = 0;

            // Synres configuration register bits
            // Bits D8 through D15 Represent Channels 1-8, 0 = channel set for synchro/resolver mode,
            //                                             1 = LVDT signal input mode.
            // Bits D0 through D7 Represent Channels 1-8, 0 = Resolver, 1 = Synchro 
            //                                            0 = 2 wire signal LVDT, 1 = 3-4 wire signal LVDT 
            int.TryParse(CardText.Text, out card);

            // CHcombox index is (0) Resolver, (1) Syncho, (2) LVDT 2 Wire, (3) LVDT 4 Wire

            synres += SynRes(CHcombo0.SelectedIndex & 0x1) * 0x01;
            synres += SynRes(CHcombo1.SelectedIndex & 0x1) * 0x02;
            synres += SynRes(CHcombo2.SelectedIndex & 0x1) * 0x04;
            synres += SynRes(CHcombo3.SelectedIndex & 0x1) * 0x08;
            synres += SynRes(CHcombo4.SelectedIndex & 0x1) * 0x10;
            synres += SynRes(CHcombo5.SelectedIndex & 0x1) * 0x20;
            synres += SynRes(CHcombo6.SelectedIndex & 0x1) * 0x40;
            synres += SynRes(CHcombo7.SelectedIndex & 0x1) * 0x80;

            synres += SynRes(CHcombo0.SelectedIndex & 0x2 >> 1) * 0x0100;
            synres += SynRes(CHcombo1.SelectedIndex & 0x2 >> 1) * 0x0200;
            synres += SynRes(CHcombo2.SelectedIndex & 0x2 >> 1) * 0x0400;
            synres += SynRes(CHcombo3.SelectedIndex & 0x2 >> 1) * 0x0800;
            synres += SynRes(CHcombo4.SelectedIndex & 0x2 >> 1) * 0x1000;
            synres += SynRes(CHcombo5.SelectedIndex & 0x2 >> 1) * 0x2000;
            synres += SynRes(CHcombo6.SelectedIndex & 0x2 >> 1) * 0x4000;
            synres += SynRes(CHcombo7.SelectedIndex & 0x2 >> 1) * 0x8000;

            int err = CCC_cpci.ccc_SD_setSynResAll(card, synres);
            CerrorText.Text = String.Format("{0:d}", err);
        }

        private int SynRes(int CHselect)
        {
            int synres = 0;
            switch(CHselect)
            {
                case 0: synres = 0; break;
                case 1: synres = 1;break;
                case 2: synres = 0x100;break;
                case 3: synres = 0x101;break;
            }
            return synres;
        }

        private void SetDACoffset_Click(object sender, EventArgs e)
        {
            int card = 0;
            int channel = 0;
            double offset = 0;

            int.TryParse(CardText.Text, out card);
            int.TryParse(DACchText.Text, out channel);

            double.TryParse(DACoffsetText.Text, out offset);
 
            int err = CCC_cpci.ccc_SD_setDac_Offset(card, channel, offset);
            DACerrorText.Text = String.Format("{0:d}", err);
        }

        private void SetActive_Click(object sender, EventArgs e)
        {
            int card = 0;
            int active = 0;

            int.TryParse(CardText.Text, out card);
            if (CHactive0.Checked) active += 0x01;
            if (CHactive1.Checked) active += 0x02;
            if (CHactive2.Checked) active += 0x04;
            if (CHactive3.Checked) active += 0x08;
            if (CHactive4.Checked) active += 0x10;
            if (CHactive5.Checked) active += 0x20;
            if (CHactive6.Checked) active += 0x40;
            if (CHactive7.Checked) active += 0x80;
            int err = CCC_cpci.ccc_SD_setActiveChannel(card, active);
            AerrorText.Text = String.Format("{0:d}", err);
        }

        private void SetRef_Click(object sender, EventArgs e)
        {
            int card = 0;
            int channel = 0;
            double freq = 0;
            double volts = 0;

            int.TryParse(CardText.Text, out card);
            int.TryParse(RChannelText.Text, out channel);

            double.TryParse(FreqText.Text, out freq);
            double.TryParse(VoltsText.Text, out volts);

            int err = CCC_cpci.ccc_SD_setChanRefFreq(card, channel, freq);
            FreqerrorText.Text = String.Format("{0:d}", err);
            err = CCC_cpci.ccc_SD_setChanRefVoltage(card, channel, volts);
            VoltserrorText.Text = String.Format("{0:d}", err);
        }


        private void ReadButton_Click(object sender, EventArgs e)
        {
            int card = 0;
            int channel = 0;
            double angle = 0;
            int velocity = 0;
            int astatus = 0;
            int vstatus = 0;

            int.TryParse(CardText.Text, out card);
            int.TryParse(MChannelText.Text, out channel);
            int aerr = CCC_cpci.ccc_SD_getAngle_stat(card, channel, ref angle, ref astatus);
            int verr = CCC_cpci.ccc_SD_getVelocity_stat(card, channel, ref velocity, ref vstatus);

            StatusText.Text = String.Format("Hex {0:x}", astatus);
            Angle.Text = String.Format("{0:f4}", angle);
            Velocity.Text = String.Format("{0:d}", velocity);
 
        }

        private void ReadAnglesButton_Click(object sender, EventArgs e)
        {
            int card = 0;
            int.TryParse(CardText.Text, out card);
            bool start = (ResultsRichText.Lines.GetLength(0) < 2);
            double angle = 0;
            int astatus = 0;
            StringBuilder hstr = new StringBuilder();
            StringBuilder astr = new StringBuilder("A");
            for (int ich = 0; ich < 8; ich++)
            {
                int aerr = CCC_cpci.ccc_SD_getAngle_stat(card, ich, ref angle, ref astatus);
                hstr.Append("\tCH" + ich.ToString());
                astr.Append("\t" + String.Format("{0:f5}", angle));
            }
            hstr.AppendLine();
            astr.AppendLine();
            if (start)
            {
                ResultsRichText.AppendText(hstr.ToString());
            }
            ResultsRichText.AppendText(astr.ToString());
        }

        private void ReadVelocitiesButton_Click(object sender, EventArgs e)
        {
            int card = 0;
            int.TryParse(CardText.Text, out card);
            bool start = (ResultsRichText.Lines.GetLength(0) < 1);
            int velocity = 0;
            int vstatus = 0; 
            StringBuilder hstr = new StringBuilder();
            StringBuilder vstr = new StringBuilder("V");
            for (int ich = 0; ich < 8; ich++)
            {
                int verr = CCC_cpci.ccc_SD_getVelocity_stat(card, ich, ref velocity, ref vstatus);
                hstr.Append("\tCH" + ich.ToString());
                vstr.Append("\t" + String.Format("{0:d}", velocity));
            }
            hstr.AppendLine();
            vstr.AppendLine();
            if (start)
            {
                ResultsRichText.AppendText(hstr.ToString());
            }
            ResultsRichText.AppendText(vstr.ToString());
        }

        private void ClearButton_Click(object sender, EventArgs e)
        {
            ResultsRichText.Clear();
        }

        private void CopyButton_Click(object sender, EventArgs e)
        {
            ResultsRichText.SelectAll();
            ResultsRichText.Copy();
            ResultsRichText.Select(0,0);
        }

        private void CardInfoButton_Click(object sender, EventArgs e)
        {
            int card = 0;
            StringBuilder cpath = new StringBuilder("                         ", 300);
            StringBuilder location = new StringBuilder("                      ", 300);
            //int dplen = 0;
            //int loclen = 0;

            bool cardOK = int.TryParse(CardText.Text, out card);
            int err = CCC_cpci.ccc_synres_info(card, cpath, location);
            //cpath.Length = dplen;
            //location.Length = loclen;
            CardPathText.Text = cpath.ToString();
            LocationText.Text = location.ToString();
        }

    }
}