﻿using System.Runtime.InteropServices;
using System.Text;

namespace CCC_Demo
{
    class CCC_cpci
    {
        //  FOR ALL FUNCTIONS:
        //  return 0 = no error,  Return > 0 see defined error codes above
        //  card is a valid card number (1 for single card, 2... for multiple cards)
        //  For measurement results the calling program provides pointers to existing variables in the calling program  
        [DllImport("ccc_syncres_api.dll", EntryPoint = "ccc_syncres_info", CharSet = CharSet.Auto)]
        public static extern int ccc_synres_info(int card, [MarshalAs(UnmanagedType.LPWStr)] StringBuilder dpathptr,
                [MarshalAs(UnmanagedType.LPWStr)] StringBuilder locationptr);

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_getAngle")] 
        public static extern int ccc_SD_getAngle(int card, int channel, ref double angle);
        // channel is a valid channel number (1-8)
        // angle = absolute position of channel selected (1-8), scaled in degrees: 0 - 359.9995  
        // Corresponds with Board Registers base+ 000h - 01Ch as channels 1-8 respectively.

        [DllImportAttribute("ccc_syncres_api.dll", EntryPoint = "ccc_SD_getAngle_stat")]
        public static extern int ccc_SD_getAngle_stat(int card, int channel, ref double angle, ref int status);
        // channel is a valid channel number (1-8)
        // angle = absolute position of channel selected, scaled in degrees: 0 - 359.9995  
        // status = status in lower 16 bits
        // Corresponds to Board Registers, of base+ 000h - 01Ch as channels 1-8 respectively for position read low word, for status high word and'd with 00FFh for each. 

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_getAngle_stat")] 
        public static extern int ccc_SD_getBinAngle(int card, int channel, ref int angle);
        // channel is a valid channel number (1-8)
        // angle = absolute position of channel selected, in a Binary Weighted Angle format 0-65535 (representing 0 to 359.995 degrees)  
        // Corresponds to Board Registers base+ 000h - 01Ch as channels 1-8 respectively. 

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_getBinAngle_stat")] 
        public static extern int ccc_SD_getBinAngle_stat(int card, int channel, ref int angle, ref int status);
        // channel is a valid channel number (1-8)
        // angle = absolute position of channel selected, in a Binary Weighted Angle format 0-65535 (representing 0 to 359.995 degrees)  
        // status = status in lower 16 bits
        // Corresponds to Board Registers, of base+ 000h - 01Ch as channels 1-8 respectively for position read low word, for status high word and'd with 00FFh for each. 

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_getVelocity")] 
        public static extern int ccc_SD_getVelocity(int card, int channel, ref int velocity);
        // channel is a valid channel number (1-8)
        // velocity = velocity of channel selected, 0 to + 32768 -32767
        // Corresponds with Board Registers base+ 020h - 03Ch as channels 1-8 respectively.

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_getVelocity_stat")] 
        public static extern int ccc_SD_getVelocity_stat(int card, int channel, ref int velocity, ref int status);
        // channel is a valid channel number (1-8)
        // velocity =velocity of channel selected, 0 to + 32768 -32767
        // status = status in lower 16 bits
        // Corresponds with Board Registers base+ 020h - 03Ch as channels 1-8 respectively.

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_setChanRefFreq")] 
        public static extern int ccc_SD_setChanRefFreq(int card, int channel, double frequency);
        // channel is a valid channel number (1-4)
        // frequency = Reference Frequency for the specified channel in range 360 to 10,000 Hz. 
        // Write Frequency first, prior writing or setting Voltage magnitude for selected programmable reference supply. 
        // Corresponds with Board Registers base+ 120h - 12Ch as channels 1-4 respectively.

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_setRefFreq")]
        public static extern int ccc_SD_setRefFreq(int card, double frequency);
        // just for cards with only 1 Programmable Reference Supply on-board
        // frequency = Reference Frequency for the specified channel in range 360 to 10,000 Hz. 
        // Write Frequency first, prior writing or setting Voltage magnitude for selected programmable reference supply. 
        // alternate, cards with only 1 Programmable Reference Supply on-board can use the following without a channel select required:
        // Corresponds with Board Registers base+ 120h

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_setChanRefVoltage")]  
        public static extern int ccc_SD_setChanRefVoltage(int card, int channel, double voltage);
        // channel is a valid channel number (1-4)
        // voltage = Reference Voltage for the specified channel 
        //	   valid range is 0 or 20 to 280 = 2.0 to 28.0 VAC (Low voltage units)
        //	   valid range is 0 or 360 to 1150 = 36 to 115 VAC (High voltage units)
        //	   scale 0 to 28 : 0 to 115 represented by type units (model), call / range undifferentiated								
        // Write Frequency first, prior writing or setting Voltage magnitude for selected programmable reference supply. 
        // Reference loss detected by Loss of Reference error indication on channel read or D-S self test status. 
        // Corresponds with Board Registers base+ 130h - 13Ch as channels 1-4 respectively.

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_setRefVoltage")] 
        public static extern int ccc_SD_setRefVoltage(int card, double voltage);
        // just for cards with only 1 Programmable Reference Supply on-board
        // voltage = Reference Voltage for the specified channel 
        //	   valid range is 0 or 20 to 280 = 2.0 to 28.0 VAC (Low voltage units)
        //	   valid range is 0 or 360 to 1150 = 36 to 115 VAC (High voltage units)
        //	   scale 0 to 28 : 0 to 115 represented by type units (model), call / range undifferentiated								
        // Write Frequency first, prior writing or setting Voltage magnitude for selected programmable reference supply. 
        // Corresponds with Board Register base+ 130h

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_setActiveChannel")]  
        public static extern int ccc_SD_setActiveChannel(int card, int active);
        // active = active channel mask, D0 - D7 Represent Channels 1-8 respectively.
        // 1 = Set Present and active, 0 = Not Active = Disable to void fault detects for respective channel. 
        // Corresponds with Board Register base+ 0A0h respectively.

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_setSynResAll")]  
        public static extern int ccc_SD_setSynResAll(int card, int SynRes);
        // SynRes = channel signal format
        // 	Bits D0 through D7 set signal format for Channels 1-8
        //		0 = Resolver, or 2 wire signal LVDT
        //		1 = Synchro, or 3-4 wire signal LVDT 
        //
        // 	Bits D8 through D15 set signal format for Channels 1-8, 
        //		0 = channel set for synchro/resolver mode
        //		1 = LVDT signal input mode.
        //
        //		Examples:
        //		0000h + 0003h = channels 1 and 2 are synchro, channels 3-8 are Resolver
        // 	FF00h + 00FFh = all 3-4 wire LVDT signal feedback.
        // Not all selections available on all models, consult model select guide.
        // Corresponds with Board Register base+ 0A8h respectively.

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_setDac_Offset")] 
        public static extern int ccc_SD_setDac_Offset(int card, int channel, double dacoffset);
        // channel is a valid channel number (1-4)
        // dacoffset = offset in degrees for analog output on selected channel = 0 to 359.995 degrees.
        // Analog DC output is 0 to +10VDC for 0 to +179.999 degrees, 0 to -10VDC for 0 to -179.999 degrees.  
        // DAC offset is subtracted from the DAC Output setting to create the Analog output signal
        // Corresponds with Board Registers base+ 060h - 06Ch as channels 1-4 respectively.

        [DllImportAttribute("ccc_syncres_api.dll",EntryPoint="ccc_SD_setBinDac_Offset")] 
        public static extern int ccc_SD_setBinDac_Offset(int card, int channel, int dacoffset);
        // channel is a valid channel number (1-4)
        // dacoffset  = offset in binary for analog output on selected channel = 0 to 65535 ( corresponds to  0 to 359.995 degrees).
        // Analog DC output is 0 to +10VDC for 0 to +32767, 0 to -10VDC for 0 -32768.  
        // DAC offset is subtracted from the DAC Output setting to create the Analog output signal
        // Corresponds with Board Registers base+ 060h - 06Ch as channels 1-4 respectively.


    }
}
